@@ -8,7 +8,7 @@ use Data::Dumper;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 our $AUTOLOAD;
 
 sub new {
@@ -30,7 +30,7 @@ sub add_aiapplication {
     my $app     = "ai";
     my $args    = {};
 
-    foreach my $data ('post_prompt', 'post_prompt_url', 'post_prompt_auth_user', 'post_prompt_auth_password', 'languages', 'hints', 'params', 'prompt', 'SWAIG', 'pronounce') {
+    foreach my $data ('post_prompt', 'post_prompt_url', 'post_prompt_auth_user', 'post_prompt_auth_password', 'languages', 'hints', 'params', 'prompt', 'SWAIG', 'pronounce', 'agent_meta_data') {
 	next unless $self->{"_$data"};
 	$args->{$data} = $self->{"_$data"};
     }
@@ -63,6 +63,15 @@ sub set_aipost_prompt_url {
     return;
 }
 
+# Set agent_meta_data 
+sub set_aimeta_data {
+    my $self = shift;
+
+    $self->{_agent_meta_data} = shift;
+
+    return;
+}
+
 # Set params overriding any previously set params
 sub set_aiparams {
     my $self = shift;
